<div align=center>

# Beryl-Events-Utils

![PyPI](https://img.shields.io/pypi/v/beryl-events-utils?label=PyPi&logo=pypi&logoColor=white) ![PyPI - Python Version](https://img.shields.io/pypi/pyversions/beryl-events-utils?label=Python&logo=python&logoColor=white) ![PyPI - Downloads](https://img.shields.io/pypi/dd/beryl-events-utils?label=PyPi%20Downloads&logo=pypi&logoColor=white)

A set of async utils for Beryl's Events system

<div align=left>

# Info

Beryl, which is a discord bot offers a events system, where users can set an event and then later check how much more days is there left. The events system is powered off of MongoDB and thus requires an MongoDB server in order to use. These are the base corountines used by Beryl.

# Installation

## Pip

```sh
pip install beryl-events-utils
```

## Poetry

```sh
poetry add beryl-events-utils
```

# License

MIT
